@@ -32,6 +32,11 @@ along with pktools.  If not, see <http://www.gnu.org/licenses/>.
 #define RAD2DEG(RAD) (RAD/PI*180)
 #endif
 
+#ifdef WIN32
+#include <process.h>
+#define getpid _getpid
+#endif
+
 #include <assert.h>
 #include <math.h>
 #include <limits>
@@ -111,11 +116,15 @@ public:
   void var(const std::string& inputFilename, const std::string& outputFilename, int dim, bool disc=false);
   void morphology(const ImgReaderGdal& input, ImgWriterGdal& output, const std::string& method, int dimX, int dimY, const std::vector<double> &angle, bool disc=false);
   template<class T> unsigned long int morphology(const Vector2d<T>& input, Vector2d<T>& output, const std::string& method, int dimX, int dimY, bool disc=false, double hThreshold=0);
+  template<class T> unsigned long int dsm2dtm_nwse(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim=3);
+  template<class T> unsigned long int dsm2dtm_nesw(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim=3);
+  template<class T> unsigned long int dsm2dtm_senw(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim=3);
+  template<class T> unsigned long int dsm2dtm_swne(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim=3);
   template<class T> void shadowDsm(const Vector2d<T>& input, Vector2d<T>& output, double sza, double saa, double pixelSize, short shadowFlag=1);
   void shadowDsm(const ImgReaderGdal& input, ImgWriterGdal& output, double sza, double saa, double pixelSize, short shadowFlag=1);
   void dwt_texture(const std::string& inputFilename, const std::string& outputFilename,int dim, int scale, int down=1, int iband=0, bool verbose=false);
   void shift(const ImgReaderGdal& input, ImgWriterGdal& output, double offsetX=0, double offsetY=0, double randomSigma=0, RESAMPLE resample=BILINEAR, bool verbose=false);
-  template<class T> void shift(const Vector2d<T>& input, Vector2d<T>& output, double offsetX=0, double offsetY=0, double randomSigma=0, RESAMPLE resample=0, bool verbose=false);
+  template<class T> void shift(const Vector2d<T>& input, Vector2d<T>& output, double offsetX=0, double offsetY=0, double randomSigma=0, RESAMPLE resample=NEAR, bool verbose=false);
   void linearFeature(const Vector2d<float>& input, std::vector< Vector2d<float> >& output, float angle=361, float angleStep=1, float maxDistance=0, float eps=0, bool l1=true, bool a1=true, bool l2=true, bool a2=true, bool verbose=false);
   void linearFeature(const ImgReaderGdal& input, ImgWriterGdal& output, float angle=361, float angleStep=1, float maxDistance=0, float eps=0, bool l1=true, bool a1=true, bool l2=true, bool a2=true, int band=0, bool verbose=false);
   
@@ -358,14 +367,14 @@ template<class T1, class T2> void Filter2d::doit(const Vector2d<T1>& inputVector
         if(windowBuffer.empty())
           outBuffer[x/down]=noDataValue;
         else
-          outBuffer[x/down]=stat.min(windowBuffer);
+          outBuffer[x/down]=stat.mymin(windowBuffer);
         break;
       }
       case(filter2d::ismin):{
         if(windowBuffer.empty())
           outBuffer[x/down]=noDataValue;
         else
-          outBuffer[x/down]=(stat.min(windowBuffer)==windowBuffer[centre])? 1:0;
+          outBuffer[x/down]=(stat.mymin(windowBuffer)==windowBuffer[centre])? 1:0;
         break;
       }
       case(filter2d::minmax):{
@@ -386,14 +395,14 @@ template<class T1, class T2> void Filter2d::doit(const Vector2d<T1>& inputVector
         if(windowBuffer.empty())
           outBuffer[x/down]=noDataValue;
         else
-          outBuffer[x/down]=stat.max(windowBuffer);
+          outBuffer[x/down]=stat.mymax(windowBuffer);
         break;
       }
       case(filter2d::ismax):{
         if(windowBuffer.empty())
           outBuffer[x/down]=noDataValue;
         else
-          outBuffer[x/down]=(stat.max(windowBuffer)==windowBuffer[centre])? 1:0;
+          outBuffer[x/down]=(stat.mymax(windowBuffer)==windowBuffer[centre])? 1:0;
         break;
       }
       case(filter2d::order):{
@@ -402,8 +411,8 @@ template<class T1, class T2> void Filter2d::doit(const Vector2d<T1>& inputVector
         else{
           double lbound=0;
           double ubound=dimX*dimY;
-          double theMin=stat.min(windowBuffer);
-          double theMax=stat.max(windowBuffer);
+          double theMin=stat.mymin(windowBuffer);
+          double theMax=stat.mymax(windowBuffer);
           double scale=(ubound-lbound)/(theMax-theMin);
           outBuffer[x/down]=static_cast<short>(scale*(windowBuffer[centre]-theMin)+lbound);
         }
@@ -707,14 +716,14 @@ template<class T> unsigned long int Filter2d::morphology(const Vector2d<T>& inpu
         if(statBuffer.size()){
           switch(getFilterType(method)){
           case(filter2d::dilate):
-            if(output[y][x]<stat.max(statBuffer)-hThreshold){
-              output[y][x]=stat.max(statBuffer);
+            if(output[y][x]<stat.mymax(statBuffer)-hThreshold){
+              output[y][x]=stat.mymax(statBuffer);
               ++nchange;
             }
             break;
           case(filter2d::erode):
-            if(output[y][x]>stat.min(statBuffer)+hThreshold){
-              output[y][x]=stat.min(statBuffer);
+            if(output[y][x]>stat.mymin(statBuffer)+hThreshold){
+              output[y][x]=stat.mymin(statBuffer);
               ++nchange;
             }
             break;
@@ -742,6 +751,370 @@ template<class T> unsigned long int Filter2d::morphology(const Vector2d<T>& inpu
   return nchange;
 }
 
+ template<class T> unsigned long int Filter2d::dsm2dtm_nwse(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim)
+{
+  const char* pszMessage;
+  void* pProgressArg=NULL;
+  GDALProgressFunc pfnProgress=GDALTermProgress;
+  double progress=0;
+  pfnProgress(progress,pszMessage,pProgressArg);
+
+  Vector2d<T> tmpDSM(inputDSM);
+  double noDataValue=0;
+  if(m_noDataValues.size())
+    noDataValue=m_noDataValues[0];
+
+  unsigned long int nchange=0;
+  int dimX=dim;
+  int dimY=dim;
+  assert(dimX);
+  assert(dimY);
+  statfactory::StatFactory stat;
+  Vector2d<T> inBuffer(dimY,inputDSM.nCols());
+  if(outputMask.size()!=inputDSM.nRows())
+    outputMask.resize(inputDSM.nRows());
+  int indexI=0;
+  int indexJ=0;
+  //initialize last half of inBuffer
+  for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+    for(int i=0;i<inputDSM.nCols();++i)
+      inBuffer[indexJ][i]=tmpDSM[abs(j)][i];
+    ++indexJ;
+  }
+  for(int y=0;y<tmpDSM.nRows();++y){
+    if(y){//inBuffer already initialized for y=0
+      //erase first line from inBuffer
+      inBuffer.erase(inBuffer.begin());
+      //read extra line and push back to inBuffer if not out of bounds
+      if(y+dimY/2<tmpDSM.nRows()){
+        //allocate buffer
+        inBuffer.push_back(inBuffer.back());
+        for(int i=0;i<tmpDSM.nCols();++i)
+          inBuffer[inBuffer.size()-1][i]=tmpDSM[y+dimY/2][i];
+      }
+      else{
+        int over=y+dimY/2-tmpDSM.nRows();
+        int index=(inBuffer.size()-1)-over;
+        assert(index>=0);
+        assert(index<inBuffer.size());
+        inBuffer.push_back(inBuffer[index]);
+      }
+    }
+    for(int x=0;x<tmpDSM.nCols();++x){
+      double centerValue=inBuffer[(dimY-1)/2][x];
+      short nmasked=0;
+      std::vector<T> neighbors;
+      for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+	for(int i=-(dimX-1)/2;i<=dimX/2;++i){
+	  indexI=x+i;
+	  //check if out of bounds
+	  if(indexI<0)
+	    indexI=-indexI;
+	  else if(indexI>=tmpDSM.nCols())
+	    indexI=tmpDSM.nCols()-i;
+	  if(y+j<0)
+	    indexJ=-j;
+	  else if(y+j>=tmpDSM.nRows())
+	    indexJ=(dimY>2) ? (dimY-1)/2-j : 0;
+	  else
+	    indexJ=(dimY-1)/2+j;
+	  double difference=(centerValue-inBuffer[indexJ][indexI]);
+	  if(i||j)//skip centerValue
+	    neighbors.push_back(inBuffer[indexJ][indexI]);
+	  if(difference>hThreshold)
+	    ++nmasked;
+	}
+      }
+      if(nmasked<nlimit){
+	++nchange;
+	//reset pixel in outputMask
+	outputMask[y][x]=0;
+      }
+      else{
+	//reset pixel height in tmpDSM
+	inBuffer[(dimY-1)/2][x]=stat.mymin(neighbors);
+      }
+    }
+    progress=(1.0+y);
+    progress/=outputMask.nRows();
+    pfnProgress(progress,pszMessage,pProgressArg);
+  }
+  return nchange;
+}
+
+ template<class T> unsigned long int Filter2d::dsm2dtm_nesw(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim)
+{
+  const char* pszMessage;
+  void* pProgressArg=NULL;
+  GDALProgressFunc pfnProgress=GDALTermProgress;
+  double progress=0;
+  pfnProgress(progress,pszMessage,pProgressArg);
+
+  Vector2d<T> tmpDSM(inputDSM);
+  double noDataValue=0;
+  if(m_noDataValues.size())
+    noDataValue=m_noDataValues[0];
+
+  unsigned long int nchange=0;
+  int dimX=dim;
+  int dimY=dim;
+  assert(dimX);
+  assert(dimY);
+  statfactory::StatFactory stat;
+  Vector2d<T> inBuffer(dimY,inputDSM.nCols());
+  if(outputMask.size()!=inputDSM.nRows())
+    outputMask.resize(inputDSM.nRows());
+  int indexI=0;
+  int indexJ=0;
+  //initialize last half of inBuffer
+  for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+    for(int i=0;i<inputDSM.nCols();++i)
+      inBuffer[indexJ][i]=tmpDSM[abs(j)][i];
+    ++indexJ;
+  }
+  for(int y=0;y<tmpDSM.nRows();++y){
+    if(y){//inBuffer already initialized for y=0
+      //erase first line from inBuffer
+      inBuffer.erase(inBuffer.begin());
+      //read extra line and push back to inBuffer if not out of bounds
+      if(y+dimY/2<tmpDSM.nRows()){
+        //allocate buffer
+        inBuffer.push_back(inBuffer.back());
+        for(int i=0;i<tmpDSM.nCols();++i)
+          inBuffer[inBuffer.size()-1][i]=tmpDSM[y+dimY/2][i];
+      }
+      else{
+        int over=y+dimY/2-tmpDSM.nRows();
+        int index=(inBuffer.size()-1)-over;
+        assert(index>=0);
+        assert(index<inBuffer.size());
+        inBuffer.push_back(inBuffer[index]);
+      }
+    }
+    for(int x=tmpDSM.nCols()-1;x>=0;--x){
+      double centerValue=inBuffer[(dimY-1)/2][x];
+      short nmasked=0;
+      std::vector<T> neighbors;
+      for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+	for(int i=-(dimX-1)/2;i<=dimX/2;++i){
+	  indexI=x+i;
+	  //check if out of bounds
+	  if(indexI<0)
+	    indexI=-indexI;
+	  else if(indexI>=tmpDSM.nCols())
+	    indexI=tmpDSM.nCols()-i;
+	  if(y+j<0)
+	    indexJ=-j;
+	  else if(y+j>=tmpDSM.nRows())
+	    indexJ=(dimY>2) ? (dimY-1)/2-j : 0;
+	  else
+	    indexJ=(dimY-1)/2+j;
+	  double difference=(centerValue-inBuffer[indexJ][indexI]);
+	  if(i||j)//skip centerValue
+	    neighbors.push_back(inBuffer[indexJ][indexI]);
+	  if(difference>hThreshold)
+	    ++nmasked;
+	}
+      }
+      if(nmasked<nlimit){
+	++nchange;
+	//reset pixel in outputMask
+	outputMask[y][x]=0;
+      }
+      else{
+	//reset pixel height in tmpDSM
+	inBuffer[(dimY-1)/2][x]=stat.mymin(neighbors);
+      }
+    }
+    progress=(1.0+y);
+    progress/=outputMask.nRows();
+    pfnProgress(progress,pszMessage,pProgressArg);
+  }
+  return nchange;
+}
+
+ template<class T> unsigned long int Filter2d::dsm2dtm_senw(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim)
+{
+  const char* pszMessage;
+  void* pProgressArg=NULL;
+  GDALProgressFunc pfnProgress=GDALTermProgress;
+  double progress=0;
+  pfnProgress(progress,pszMessage,pProgressArg);
+
+  Vector2d<T> tmpDSM(inputDSM);
+  double noDataValue=0;
+  if(m_noDataValues.size())
+    noDataValue=m_noDataValues[0];
+
+  unsigned long int nchange=0;
+  int dimX=dim;
+  int dimY=dim;
+  assert(dimX);
+  assert(dimY);
+  statfactory::StatFactory stat;
+  Vector2d<T> inBuffer(dimY,inputDSM.nCols());
+  if(outputMask.size()!=inputDSM.nRows())
+    outputMask.resize(inputDSM.nRows());
+  int indexI=0;
+  int indexJ=0;
+  //initialize last half of inBuffer
+  for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+    for(int i=0;i<inputDSM.nCols();++i)
+      inBuffer[indexJ][i]=tmpDSM[abs(j)][i];
+    ++indexJ;
+  }
+  for(int y=tmpDSM.nRows()-1;y>=0;--y){
+    if(y){//inBuffer already initialized for y=0
+      //erase first line from inBuffer
+      inBuffer.erase(inBuffer.begin());
+      //read extra line and push back to inBuffer if not out of bounds
+      if(y+dimY/2<tmpDSM.nRows()){
+        //allocate buffer
+        inBuffer.push_back(inBuffer.back());
+        for(int i=0;i<tmpDSM.nCols();++i)
+          inBuffer[inBuffer.size()-1][i]=tmpDSM[y+dimY/2][i];
+      }
+      else{
+        int over=y+dimY/2-tmpDSM.nRows();
+        int index=(inBuffer.size()-1)-over;
+        assert(index>=0);
+        assert(index<inBuffer.size());
+        inBuffer.push_back(inBuffer[index]);
+      }
+    }
+    for(int x=tmpDSM.nCols()-1;x>=0;--x){
+      double centerValue=inBuffer[(dimY-1)/2][x];
+      short nmasked=0;
+      std::vector<T> neighbors;
+      for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+	for(int i=-(dimX-1)/2;i<=dimX/2;++i){
+	  indexI=x+i;
+	  //check if out of bounds
+	  if(indexI<0)
+	    indexI=-indexI;
+	  else if(indexI>=tmpDSM.nCols())
+	    indexI=tmpDSM.nCols()-i;
+	  if(y+j<0)
+	    indexJ=-j;
+	  else if(y+j>=tmpDSM.nRows())
+	    indexJ=(dimY>2) ? (dimY-1)/2-j : 0;
+	  else
+	    indexJ=(dimY-1)/2+j;
+	  double difference=(centerValue-inBuffer[indexJ][indexI]);
+	  if(i||j)//skip centerValue
+	    neighbors.push_back(inBuffer[indexJ][indexI]);
+	  if(difference>hThreshold)
+	    ++nmasked;
+	}
+      }
+      if(nmasked<nlimit){
+	++nchange;
+	//reset pixel in outputMask
+	outputMask[y][x]=0;
+      }
+      else{
+	//reset pixel height in tmpDSM
+	inBuffer[(dimY-1)/2][x]=stat.mymin(neighbors);
+      }
+    }
+    progress=(1.0+y);
+    progress/=outputMask.nRows();
+    pfnProgress(progress,pszMessage,pProgressArg);
+  }
+  return nchange;
+}
+
+ template<class T> unsigned long int Filter2d::dsm2dtm_swne(const Vector2d<T>& inputDSM, Vector2d<T>& outputMask, double hThreshold, int nlimit, int dim)
+{
+  const char* pszMessage;
+  void* pProgressArg=NULL;
+  GDALProgressFunc pfnProgress=GDALTermProgress;
+  double progress=0;
+  pfnProgress(progress,pszMessage,pProgressArg);
+
+  Vector2d<T> tmpDSM(inputDSM);
+  double noDataValue=0;
+  if(m_noDataValues.size())
+    noDataValue=m_noDataValues[0];
+
+  unsigned long int nchange=0;
+  int dimX=dim;
+  int dimY=dim;
+  assert(dimX);
+  assert(dimY);
+  statfactory::StatFactory stat;
+  Vector2d<T> inBuffer(dimY,inputDSM.nCols());
+  if(outputMask.size()!=inputDSM.nRows())
+    outputMask.resize(inputDSM.nRows());
+  int indexI=0;
+  int indexJ=0;
+  //initialize last half of inBuffer
+  for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+    for(int i=0;i<inputDSM.nCols();++i)
+      inBuffer[indexJ][i]=tmpDSM[abs(j)][i];
+    ++indexJ;
+  }
+  for(int y=tmpDSM.nRows()-1;y>=0;--y){
+    if(y){//inBuffer already initialized for y=0
+      //erase first line from inBuffer
+      inBuffer.erase(inBuffer.begin());
+      //read extra line and push back to inBuffer if not out of bounds
+      if(y+dimY/2<tmpDSM.nRows()){
+        //allocate buffer
+        inBuffer.push_back(inBuffer.back());
+        for(int i=0;i<tmpDSM.nCols();++i)
+          inBuffer[inBuffer.size()-1][i]=tmpDSM[y+dimY/2][i];
+      }
+      else{
+        int over=y+dimY/2-tmpDSM.nRows();
+        int index=(inBuffer.size()-1)-over;
+        assert(index>=0);
+        assert(index<inBuffer.size());
+        inBuffer.push_back(inBuffer[index]);
+      }
+    }
+    for(int x=0;x<tmpDSM.nCols();++x){
+      double centerValue=inBuffer[(dimY-1)/2][x];
+      short nmasked=0;
+      std::vector<T> neighbors;
+      for(int j=-(dimY-1)/2;j<=dimY/2;++j){
+	for(int i=-(dimX-1)/2;i<=dimX/2;++i){
+	  indexI=x+i;
+	  //check if out of bounds
+	  if(indexI<0)
+	    indexI=-indexI;
+	  else if(indexI>=tmpDSM.nCols())
+	    indexI=tmpDSM.nCols()-i;
+	  if(y+j<0)
+	    indexJ=-j;
+	  else if(y+j>=tmpDSM.nRows())
+	    indexJ=(dimY>2) ? (dimY-1)/2-j : 0;
+	  else
+	    indexJ=(dimY-1)/2+j;
+	  double difference=(centerValue-inBuffer[indexJ][indexI]);
+	  if(i||j)//skip centerValue
+	    neighbors.push_back(inBuffer[indexJ][indexI]);
+	  if(difference>hThreshold)
+	    ++nmasked;
+	}
+      }
+      if(nmasked<nlimit){
+	++nchange;
+	//reset pixel in outputMask
+	outputMask[y][x]=0;
+      }
+      else{
+	//reset pixel height in tmpDSM
+	inBuffer[(dimY-1)/2][x]=stat.mymin(neighbors);
+      }
+    }
+    progress=(1.0+y);
+    progress/=outputMask.nRows();
+    pfnProgress(progress,pszMessage,pProgressArg);
+  }
+  return nchange;
+}
+
   template<class T> void Filter2d::shadowDsm(const Vector2d<T>& input, Vector2d<T>& output, double sza, double saa, double pixelSize, short shadowFlag)
 {
   unsigned int ncols=input.nCols();
@@ -800,7 +1173,8 @@ template<class T> void Filter2d::dwtForward(Vector2d<T>& theBuffer, const std::s
   for(int irow=0;irow<theBuffer.size();++irow)
     while(theBuffer[irow].size()&(theBuffer[irow].size()-1))
       theBuffer[irow].push_back(theBuffer[irow].back());
-  double data[theBuffer.size()*theBuffer[0].size()];
+  std::vector<double> vdata(theBuffer.size()*theBuffer[0].size());
+  double* data=&(vdata[0]);
   for(int irow=0;irow<theBuffer.size();++irow){
     for(int icol=0;icol<theBuffer[0].size();++icol){
       int index=irow*theBuffer[0].size()+icol;
@@ -846,7 +1220,9 @@ template<class T> void Filter2d::dwtInverse(Vector2d<T>& theBuffer, const std::s
   for(int irow=0;irow<theBuffer.size();++irow)
     while(theBuffer[irow].size()&(theBuffer[irow].size()-1))
       theBuffer[irow].push_back(theBuffer[irow].back());
-  double data[theBuffer.size()*theBuffer[0].size()];
+  std::vector<double> vdata(theBuffer.size()*theBuffer[0].size());
+  double* data=&(vdata[0]);
+  //double data[theBuffer.size()*theBuffer[0].size()];
   for(int irow=0;irow<theBuffer.size();++irow){
     for(int icol=0;icol<theBuffer[0].size();++icol){
       int index=irow*theBuffer[0].size()+icol;
