@@ -1,6 +1,6 @@
 /**********************************************************************
 pklas2img.cc: program to create (e.g., DEM) raster image from las files
-Copyright (C) 2008-2012 Pieter Kempeneers
+Copyright (C) 2008-2014 Pieter Kempeneers
 
 This file is part of pktools
 
@@ -32,15 +32,15 @@ int main(int argc,char **argv) {
   Optionpk<string> input_opt("i", "input", "Input las file");
   Optionpk<short> nodata_opt("nodata", "nodata", "nodata value to put in image if not valid", 0);
   Optionpk<string> attribute_opt("n", "name", "names of the attribute to select: intensity, return, nreturn, z", "z");
-  Optionpk<bool> disc_opt("circ", "circular", "circular disc kernel for dilation and erosion", false);
-  Optionpk<double> maxSlope_opt("s", "maxSlope", "Maximum slope used for morphological filtering", 0.0);
-  Optionpk<double> hThreshold_opt("ht", "maxHeight", "initial and maximum height threshold for progressive morphological filtering (e.g., -ht 0.2 -ht 2.5)", 0.2);
-  Optionpk<short> maxIter_opt("maxit", "maxit", "Maximum number of iterations in post filter", 5);
-  Optionpk<short> nbin_opt("nbin", "nbin", "Number of percentile bins for calculating profile (=number of output bands)", 10.0);
+  // Optionpk<bool> disc_opt("circ", "circular", "circular disc kernel for dilation and erosion", false);
+  // Optionpk<double> maxSlope_opt("s", "maxSlope", "Maximum slope used for morphological filtering", 0.0);
+  // Optionpk<double> hThreshold_opt("ht", "maxHeight", "initial and maximum height threshold for progressive morphological filtering (e.g., -ht 0.2 -ht 2.5)", 0.2);
+  // Optionpk<short> maxIter_opt("maxit", "maxit", "Maximum number of iterations in post filter", 5);
+  Optionpk<short> nbin_opt("nbin", "nbin", "Number of percentile bins for calculating percentile height value profile (=number of output bands)", 10.0);
   Optionpk<unsigned short> returns_opt("ret", "ret", "number(s) of returns to include");
   Optionpk<unsigned short> classes_opt("class", "class", "classes to keep: 0 (created, never classified), 1 (unclassified), 2 (ground), 3 (low vegetation), 4 (medium vegetation), 5 (high vegetation), 6 (building), 7 (low point, noise), 8 (model key-point), 9 (water), 10 (reserved), 11 (reserved), 12 (overlap)");
-  Optionpk<string> composite_opt("comp", "comp", "composite for multiple points in cell (min, max, median, mean, sum, first, last, profile, number (point density)). Last: overwrite cells with latest point", "last");
-  Optionpk<string> filter_opt("fir", "filter", "filter las points (last,single,multiple,all).", "all");
+  Optionpk<string> composite_opt("comp", "comp", "composite for multiple points in cell (min, max, median, mean, sum, first, last, profile (percentile height values), number (point density)). Last: overwrite cells with latest point", "last");
+  Optionpk<string> filter_opt("fir", "filter", "filter las points (first,last,single,multiple,all).", "all");
   // Optionpk<string> postFilter_opt("pf", "pfilter", "post processing filter (etew_min,promorph (progressive morphological filter),bunting (adapted promorph),open,close,none).", "none");
   // Optionpk<short> dimx_opt("dimx", "dimx", "Dimension X of postFilter", 3);
   // Optionpk<short> dimy_opt("dimy", "dimy", "Dimension Y of postFilter", 3);
@@ -65,10 +65,10 @@ int main(int argc,char **argv) {
     // invalid_opt.retrieveOption(argc,argv);
     nodata_opt.retrieveOption(argc,argv);
     attribute_opt.retrieveOption(argc,argv);
-    disc_opt.retrieveOption(argc,argv);
-    maxSlope_opt.retrieveOption(argc,argv);
-    hThreshold_opt.retrieveOption(argc,argv);
-    maxIter_opt.retrieveOption(argc,argv);
+    // disc_opt.retrieveOption(argc,argv);
+    // maxSlope_opt.retrieveOption(argc,argv);
+    // hThreshold_opt.retrieveOption(argc,argv);
+    // maxIter_opt.retrieveOption(argc,argv);
     nbin_opt.retrieveOption(argc,argv);
     returns_opt.retrieveOption(argc,argv);
     classes_opt.retrieveOption(argc,argv);
@@ -99,7 +99,7 @@ int main(int argc,char **argv) {
     std::cout << "short option -h shows basic options only, use long option --help to show all options" << std::endl;
     exit(0);//help was invoked, stop processing
   }
-
+  //todo: is this needed?
   GDALAllRegister();
 
   double dfComplete=0.0;
@@ -140,15 +140,19 @@ int main(int argc,char **argv) {
   unsigned long int nPoints=0;
   unsigned long int ipoint=0;
   for(int iinput=0;iinput<input_opt.size();++iinput){
-    assert(input_opt[iinput].find(".las")!=string::npos);
+    // assert(input_opt[iinput].find(".las")!=string::npos);
     FileReaderLas lasReader;
     try{
       lasReader.open(input_opt[iinput]);
     }
     catch(string errorString){
-      cout << errorString << endl;
+      cerr << errorString << endl;
       exit(1);
     }
+    catch(...){
+      cerr << "Error opening input " << input_opt[iinput] << endl;
+      exit(2);
+    }
     nPoints=lasReader.getPointCount();
     totalPoints+=nPoints;
 
@@ -230,8 +234,7 @@ int main(int argc,char **argv) {
     for(int icol=0;icol<ncol;++icol)
       outputData[irow][icol]=0;
 
-
-  std::cout << "Reading " << input_opt.size() << " las files" << std::endl;
+  cout << "Reading " << input_opt.size() << " point cloud files" << endl;
   pfnProgress(progress,pszMessage,pProgressArg);
   for(int iinput=0;iinput<input_opt.size();++iinput){
     FileReaderLas lasReader;
@@ -242,6 +245,12 @@ int main(int argc,char **argv) {
       cout << errorString << endl;
       exit(1);
     }
+    if(verbose_opt[0]){
+      if(lasReader.isCompressed())
+	cout << "Reading compressed point cloud " << input_opt[iinput]<< endl;
+      else
+	cout << "Reading uncompressed point cloud " << input_opt[iinput] << endl;
+    }
     //set bounding filter
     // lasReader.addBoundsFilter(minULX,maxULY,maxLRX,minLRY);
     //set returns filter
@@ -286,10 +295,10 @@ int main(int argc,char **argv) {
         continue;
       if((filter_opt[0]=="multiple")&&(thePoint.GetNumberOfReturns()<2))
         continue;
-      if(filter_opt[0]=="last"){
-        if(thePoint.GetReturnNumber()!=thePoint.GetNumberOfReturns())
-          continue;
-      }
+      if((filter_opt[0]=="last")&&(thePoint.GetReturnNumber()!=thePoint.GetNumberOfReturns()))
+	continue;
+      if((filter_opt[0]=="first")&&(thePoint.GetReturnNumber()!=1))
+	continue;
       double dcol,drow;
       outputWriter.geo2image(thePoint.GetX(),thePoint.GetY(),dcol,drow);
       int icol=static_cast<int>(dcol);
@@ -352,9 +361,9 @@ int main(int argc,char **argv) {
       else{
         statfactory::StatFactory stat;
         if(composite_opt[0]=="min")
-          outputData[irow][icol]=stat.min(inputData[irow][icol]);
+          outputData[irow][icol]=stat.mymin(inputData[irow][icol]);
         else if(composite_opt[0]=="max")
-          outputData[irow][icol]=stat.max(inputData[irow][icol]);
+          outputData[irow][icol]=stat.mymax(inputData[irow][icol]);
         else if(composite_opt[0]=="median")
           outputData[irow][icol]=stat.median(inputData[irow][icol]);
         else if(composite_opt[0]=="mean")
