@@ -1,6 +1,6 @@
 /**********************************************************************
-pkstat.cc: program to calculate basic statistics from raster image
-Copyright (C) 2008-2012 Pieter Kempeneers
+pkstatascii.cc: program to calculate basic statistics from raster image
+Copyright (C) 2008-2014 Pieter Kempeneers
 
 This file is part of pktools
 
@@ -56,7 +56,7 @@ int main(int argc, char *argv[])
   Optionpk<bool> histogram2d_opt("hist2d","hist2d","calculate 2-dimensional histogram based on two columns",false);
   Optionpk<short> nbin_opt("nbin","nbin","number of bins to calculate histogram");
   Optionpk<bool> relative_opt("rel","relative","use percentiles for histogram to calculate histogram",false);
-  Optionpk<double> kde_opt("kde","kde","bandwith of kernel density when producing histogram, use 0 for practical estimation based on Silverman's rule of thumb. Leave empty if no kernel density is required");
+  Optionpk<bool> kde_opt("kde","kde","Use Kernel density estimation when producing histogram. The standard deviation is estimated based on Silverman's rule of thumb",false);
   Optionpk<bool> correlation_opt("cor","correlation","calculate Pearson produc-moment correlation coefficient between two columns (defined by -c <col1> -c <col2>",false);
   Optionpk<bool> rmse_opt("rmse","rmse","calculate root mean square error between two columns (defined by -c <col1> -c <col2>",false);
   Optionpk<bool> reg_opt("reg","regression","calculate linear regression error between two columns (defined by -c <col1> -c <col2>",false);
@@ -194,20 +194,20 @@ int main(int argc, char *argv[])
     if(median_opt[0])
       cout << "median value column " << col_opt[icol] << ": " << stat.median(dataVector[icol]) << endl;
     if(minmax_opt[0]){
-      cout << "min value column " << col_opt[icol] << ": " << stat.min(dataVector[icol]) << endl;
-      cout << "max value column " << col_opt[icol] << ": " << stat.max(dataVector[icol]) << endl;
+      cout << "min value column " << col_opt[icol] << ": " << stat.mymin(dataVector[icol]) << endl;
+      cout << "max value column " << col_opt[icol] << ": " << stat.mymax(dataVector[icol]) << endl;
     }
     if(min_opt[0])
-      cout << "min value column " << col_opt[icol] << ": " << stat.min(dataVector[icol]) << endl;
+      cout << "min value column " << col_opt[icol] << ": " << stat.mymin(dataVector[icol]) << endl;
     if(max_opt[0])
-      cout << "max value column " << col_opt[icol] << ": " << stat.max(dataVector[icol]) << endl;
+      cout << "max value column " << col_opt[icol] << ": " << stat.mymax(dataVector[icol]) << endl;
     if(histogram_opt[0]){
       //todo: support kernel density function and estimate sigma as in practical estimate of the bandwith in http://en.wikipedia.org/wiki/Kernel_density_estimation
       double sigma=0;
-      if(kde_opt.size()){
-        if(kde_opt[0]>0)
-          sigma=kde_opt[0];
-        else
+      if(kde_opt[0]){//.size()){
+        // if(kde_opt[0]>0)
+        //   sigma=kde_opt[0];
+        // else
           sigma=1.06*sqrt(stat.var(dataVector[icol]))*pow(dataVector[icol].size(),-0.2);
       }
       assert(nbin);
@@ -318,10 +318,10 @@ int main(int argc, char *argv[])
     assert(dataVector[0].size()==dataVector[1].size());
     double sigma=0;
     //kernel density estimation as in http://en.wikipedia.org/wiki/Kernel_density_estimation
-    if(kde_opt.size()){
-      if(kde_opt[0]>0)
-        sigma=kde_opt[0];
-      else
+    if(kde_opt[0]){
+      // if(kde_opt[0]>0)
+      //   sigma=kde_opt[0];
+      // else
         sigma=1.06*sqrt(sqrt(stat.var(dataVector[0]))*sqrt(stat.var(dataVector[0])))*pow(dataVector[0].size(),-0.2);
     }
     assert(nbin);
